
import {
  scaleLinear,
  extent,
  scaleTime,
  timeFormat,
  histogram as bin,
  timeMonths,
  sum,
  max, 
  line, 
  curveNatural
} from 'd3';

import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';

//const width = 960;
const margin = {
  top: 0,
  right: 30,
  bottom: 30,
  left: 80,
};
const xAxisLabelOffset = 25;
const yAxisLabelOffset = 35;

export const DateHistogram = ({ data, width, height }) => {
	const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.right - margin.left;
 	
  const circleRadius = 3;
  
  const xValue = (d) => d['Reported Date'];
  const xAxisLabel = 'Time';
  
  const yValue = (d) => d['Total Dead and Missing'];
  const yAxisLabel = 'Total Dead and Missing';

  const xAxisTickFormat = timeFormat('%m/%d/%Y');
 	
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
  	.nice();

  const [start, stop] = xScale.domain();  

	const binnedData = bin()
		.value(xValue)		
		.domain(xScale.domain())
		.thresholds(timeMonths(start, stop))
  	(data)
  .map(array => ({
  	y: sum(array, yValue),
    x0: array.x0,
    x1: array.x1
  }));
  
  const yScale = scaleLinear()
    .domain([0, max(binnedData, d => d.y)])
    .range([innerHeight, 0])
  	.nice();
  
  return (
    <>
    <rect width={width} height={height} fill='white'/>
  	<g
        transform={`translate(${margin.left}, ${margin.top})`}
      >
      
      <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          tickFormat={xAxisTickFormat}
          tickOffset={8}
        />
        <AxisLeft yScale={yScale} innerWidth={innerWidth} tickOffset={5}/>
        <text
          className="axis-label"
          x={innerWidth / 2}
          y={innerHeight + xAxisLabelOffset}
          textAnchor="middle"
        >
          {xAxisLabel}
        </text>
        <text
          className="axis-label"
          
          textAnchor="middle"
          transform={`translate(${-yAxisLabelOffset},
          ${innerHeight / 2}) rotate(-90) `}
        >
          {yAxisLabel}
        </text>
      
        <Marks
          binnedData={binnedData}
          yScale={yScale}
          xScale={xScale}
          tooltipFormat={d => d}
          circleRadius={circleRadius}
          innerHeight={innerHeight}
        />
      </g>
      </>
  );
};